@@ -1,21 +1,6 @@
-/*
- * Copyright (C) 2016 ~ 2019 Deepin Technology Co., Ltd.
- *
- * Author:     jouyouyun <jouyouwen717@gmail.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 2018 - 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
 
 package main
 
@@ -27,9 +12,9 @@ import (
 	"os"
 	"path/filepath"
 
+	"github.com/godbus/dbus"
 	"github.com/linuxdeepin/go-dbus-factory/com.deepin.sessionmanager"
 	"github.com/linuxdeepin/go-gir/gio-2.0"
-	"github.com/godbus/dbus"
 	"github.com/linuxdeepin/go-lib/log"
 )
 
@@ -53,23 +38,26 @@ func main() {
 		os.Exit(1)
 	}
 	arg := flag.Arg(0)
-
+	var scheme string
 	u, err := url.Parse(arg)
 	if err != nil {
-		logger.Warningf("failed to parse url %q: %v", arg, err)
+		gFile := gio.FileNewForCommandlineArg(arg)
+		scheme = gFile.GetUriScheme()
+		if scheme == "" {
+			logger.Warningf("failed to parse url %q: %v", arg, err)
+		}
+	} else {
+		scheme = u.Scheme
+	}
+	switch scheme {
+	case "file":
+		err = openFile(u.Path)
+
+	case "":
 		err = openFile(arg)
 
-	} else {
-		switch u.Scheme {
-		case "file":
-			err = openFile(u.Path)
-
-		case "":
-			err = openFile(arg)
-
-		default:
-			err = openScheme(u.Scheme, arg)
-		}
+	default:
+		err = openScheme(scheme, arg)
 	}
 	if err != nil {
 		logger.Warning("open failed:", err)
